@@ -3,7 +3,7 @@ package Pod::Weaver::Section::SQL;
 # ABSTRACT: Document SQL more easily by referencing only the SQL command in POD
 
 
-use List::Util qw/any/;
+use List::Util 1.33 qw/any/;
 
 use Moose;
 with 'Pod::Weaver::Role::Section';
@@ -150,12 +150,14 @@ sub _format_sql {
     my %words;
     map { $words{$_} = 1 } split ' ', $content;
 
+    $content =~ s/C<([^>]+)>/C\[__\?:__$1__:\?__\]/g;
+
     for my $word ( keys %words ) {
         if ( any { $word eq $_ } @{ $self->keywords } ) {
             my $new_word = $word;
             $new_word =~ s/</E\[__?:__lt__:?__\]/;
             $new_word =~ s/>/E\[__?:__gt__:?__\]/;
-            $content =~ s/$word/B\[__?:__${new_word}__:?__\]/g;
+            $content =~ s/(^| |\n)${word}( |$)/${1}B\[__?:__${new_word}__:?__\]${2}/g;
         }
     }
 
@@ -178,7 +180,7 @@ Pod::Weaver::Section::SQL - Document SQL more easily by referencing only the SQL
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
